@@ -101,9 +101,10 @@ def getLatestTx(connection, schema, public_address, min_timestamp):
 
 def getTxSortedAsc(connection, schema, public_address_list):
 
-    queryStr = "SELECT tx_timestamp, tx_from, amount_fee_value, amount_fee_dwh_token_id,  \
-                        amount_send_value, amount_send_dwh_token_id, \
-                        amount_recv_value, amount_recv_dwh_token_id  \
+    queryStr = "SELECT id, tx_hash, tx_failed, tx_type_no, tx_timestamp, tx_from, \
+                        amount_fee_value, amount_fee_value_USD, amount_fee_dwh_token_id,  \
+                        amount_send_value, amount_send_value_USD, amount_send_dwh_token_id, \
+                        amount_recv_value, amount_recv_value_USD, amount_recv_dwh_token_id \
                 FROM {}.dwh_transaction \
                 WHERE public_address IN " + public_address_list + " \
                 ORDER BY tx_timestamp ASC"
@@ -111,4 +112,27 @@ def getTxSortedAsc(connection, schema, public_address_list):
     query = sql.SQL(queryStr).format(sql.Identifier(schema))
 
     result = herokuDbAccess.fetchDataInDatabase(query, [], connection) 
-    return result
\ No newline at end of file
+
+    retData = []
+    
+    for tx in result:
+        data = {
+            'tx_id': tx[0]
+            , 'tx_hash': tx[1]
+            , 'tx_failed': tx[2]
+            , 'tx_type_no': tx[3]
+            , 'tx_datetime': tx[4]
+            , 'tx_from': tx[5]
+            , 'tx_fee_amount': tx[6]
+            , 'tx_fee_amount_usd': tx[7]
+            , 'tx_fee_token_id': tx[8]
+            , 'tx_send_amount': tx[9]
+            , 'tx_send_amount_usd': tx[10]
+            , 'tx_send_token_id': tx[11]
+            , 'tx_recv_amount': tx[12]
+            , 'tx_recv_amount_usd': tx[13]
+            , 'tx_recv_token_id': tx[14]
+        }
+        retData.append(data.copy())
+
+    return retData
\ No newline at end of file
