@@ -181,8 +181,11 @@ def SELECT(connection, schema, columns:list, tableName:str, conditions:dict={}):
     conditionArray = []
     params = []
     for key in conditions.keys():
+        conditionColumnName = key
         if type(conditions[key]) == dict:
             conditionValue = conditions[key]['value']
+            if 'alias' in conditions[key]:
+                conditionColumnName = conditions[key]['alias']
             sqlTemplate = None
             if conditions[key]['operator'] == 'lt':
                 sqlTemplate = sqlTemplateLt
@@ -208,13 +211,13 @@ def SELECT(connection, schema, columns:list, tableName:str, conditions:dict={}):
         
         if type(conditionValue) == list:
             if sqlTemplate is None or sqlTemplate not in (sqlTemplateIn,sqlTemplateNotIn):
-                conditionArray.append(sqlTemplateIn.format(key,','.join(['%s'] * len(conditionValue))))
+                conditionArray.append(sqlTemplateIn.format(conditionColumnName,','.join(['%s'] * len(conditionValue))))
             else:
-                conditionArray.append(sqlTemplate.format(key,','.join(['%s'] * len(conditionValue))))
+                conditionArray.append(sqlTemplate.format(conditionColumnName,','.join(['%s'] * len(conditionValue))))
             for item in conditionValue:
                 params.append(item) 
         else:
-            conditionArray.append(sqlTemplate.format(key))
+            conditionArray.append(sqlTemplate.format(conditionColumnName))
             if conditionValue is not None:
                 params.append(conditionValue) 
    
@@ -315,13 +318,19 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
 #             'value': ["auth","blub"]
 #         },
 #         'listaccounthistory_data': None,
-#         'block_number': {
-#             'operator': 'lte',
+#         'block_number_1': {
+#             'alias': 'block_number',
+#             'operator': 'gte',
 #             'value': 1760000
+#         },
+#         'block_number_2': {
+#             'alias': 'block_number',
+#             'operator': 'lt',
+#             'value': 1900000
 #         }
 
 #     }
-#     conditions = {'transaction_type': "auth"}
+#     #conditions = {'transaction_type': "auth"}
 #     SELECT(connection,os.environ.get("ENVIRONMENT"),[],'dfi_blockchain_data',conditions)
 
 #     r = POST_BULK(connection,'dbdev','testbulk',[{'number':2}],True)
